# Generated by Django 4.2.17 on 2025-01-14 13:59

from django.db import migrations, models
import django.utils.timezone
import xj_user.utils.j_ulid_field


class Migration(migrations.Migration):

    dependencies = [
        ('xj_user', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='detailinfo',
            name='register_ip',
        ),
        migrations.RemoveField(
            model_name='detailinfo',
            name='register_time',
        ),
        migrations.AddField(
            model_name='baseinfo',
            name='register_ip',
            field=models.GenericIPAddressField(blank=True, null=True, verbose_name='注册IP'),
        ),
        migrations.AddField(
            model_name='baseinfo',
            name='register_time',
            field=models.DateTimeField(blank=True, default=django.utils.timezone.now, null=True, verbose_name='注册时间'),
        ),
        migrations.AlterField(
            model_name='baseinfo',
            name='uuid',
            field=xj_user.utils.j_ulid_field.JULIDField(blank=True, default='1jhhpa1qbz1m', max_length=32, null=True, unique=True, verbose_name='UUID'),
        ),
    ]



# Generated by Django 4.2.17 on 2025-01-14 13:59

from django.db import migrations
import xj_user.utils.j_ulid_field


class Migration(migrations.Migration):

    dependencies = [
        ('xj_user', '0002_remove_detailinfo_register_ip_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='baseinfo',
            name='uuid',
            field=xj_user.utils.j_ulid_field.JULIDField(blank=True, default='1jhhpacqmve6', max_length=32, null=True, unique=True, verbose_name='UUID'),
        ),
    ]
